pub enum UsbIpError {
ConnectionClosed,
PkgTooShort(usize),
InvalidCommand(u16),
StatusNotOk(u32),
}Expand description
The error type, used by this crate.
Variants
ConnectionClosed
The connection closed unexpectedly.
PkgTooShort(usize)
A packet was received but it was shorter than the 48 bytes required to parse the header.
InvalidCommand(u16)
A received packet contained a command, that is unknown to the USBIP specification.
StatusNotOk(u32)
A received packet had a status field set to an unknown status value.